#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-types
version:              0.3.8
visibility:           public
id:                   xml-types-0.3.8-Gz3On8Uo3JN2rSYUSThjSo
key:                  xml-types-0.3.8-Gz3On8Uo3JN2rSYUSThjSo
license:              MIT
maintainer:           Stephen Paul Weber <singpolyma@singpolyma.net>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://git.singpolyma.net/xml-types-haskell
synopsis:             Basic types for representing XML
description:
    Basic types for representing XML.

    The idea is to have a full set of appropriate types, which various XML
    libraries can share. Instead of having equivalent-but-incompatible types
    for every binding, parser, or client, they all share the same types can
    can thus interoperate easily.

    This library contains complete types for most parts of an XML document,
    including the prologue, node tree, and doctype. Some basic combinators
    are included for common tasks, including traversing the node tree and
    filtering children.

category:             Text, XML
abi:                  0612971e7035379d9760a38759110cbe
exposed:              True
exposed-modules:      Data.XML.Types
import-dirs:          /usr/lib/ghc-8.10.5/site-local/xml-types-0.3.8
library-dirs:         /usr/lib/ghc-8.10.5/site-local/xml-types-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/xml-types-0.3.8
hs-libraries:         HSxml-types-0.3.8-Gz3On8Uo3JN2rSYUSThjSo
depends:              base-4.14.2.0 deepseq-1.4.4.0 text-1.2.4.1
haddock-interfaces:   /usr/share/doc/haskell-xml-types/html/xml-types.haddock
haddock-html:         /usr/share/doc/haskell-xml-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

